(function($) {
   $.fn.extend({
      onShow: function(callback, unbind) {
         return this.each(function() {
            var obj = this;
            var bindopt = (unbind==undefined) ? true : unbind;
            if ($.isFunction(callback)){
               if ($(this).is(':hidden')) {
                  var checkVis = function() {
                     if ($(obj).is(':visible')) {
                        callback.call();
                        if (bindopt) {
                           $('body').unbind('click keyup keydown', checkVis);
                           $('*').unbind('dialogopen', checkVis);
                        }
                     }
                  }
                  $('body').bind('click keyup keydown', checkVis, false);
                  $('*').bind('dialogopen', checkVis, false);
               } else {
                  callback.call();
               }
            }
         });
      }
   });
})(jQuery);

function addValidationHandler(r, form, validationUrl, path) {
   $.extend(form.get(0), {
      checkRecaptcha: function(successCallback, failureCallback) {
         // First validate the recaptcha image
         $.ajax({
            type: "POST",
            url: validationUrl, 
            data: {
               "recaptcha_challenge_field": $("input[name='recaptcha_challenge_field']", form).attr("value"),
               "recaptcha_response_field": $("input[name='recaptcha_response_field']", form).attr("value"),
               "path": path
            },
            dataType: "json",
            success: function(response) {
               if (response) {
                  if (response.valid) {
                     // If it's valid then we submit as usual (where the recaptcha will be checked again)
                     successCallback();
                  } else {
                     // If it's not add a message and display a new recaptcha
                     Recaptcha._displayerror($("#" + response.message).text());
                     setTimeout(function () {
                           Recaptcha.reload();
                           $("input.clickonce", form).removeAttr("disabled");
                           if (typeof failureCallback != 'undefined') {
                              failureCallback();
                           }
                        }, 2000);
                  }
               }
            }
         });
      }
   });
   $.extend(form.validate().settings, {
      onfocusout: function(element) {
         if (!this.checkable(element)) {
           this.element(element);
         }
      },
      submitHandler: function(f) {
         f.checkRecaptcha(function() {f.submit()})
      }
   });

}
//Deal with the recaptchas which are written directly into the page on the server
function registerStaticRecaptchas() {
   var 
      r = $("#p2wRecaptcha"),
      form = r.parents("form"),
      timerId = $($("#timer_id", r).get(0)).text(),
      validationUrl = $("#hiddenContext").text() + "/recaptcha/validaterecaptcha.action";
   
   if (r.length == 0 || $("input", r).length == 0) {
      createRobotCheckbox(r, timerId);
      return;
   }
   var action = form.attr("action");
   if (action.indexOf(document.location.protocol) == 0) {
      action = action.substring(document.location.protocol.length + 2);
      action = action.substring(action.indexOf("/"));
   }
   if (timerId != null) {
        $('<input type="hidden">').attr({
           name: "timer_id",
           value: timerId
        }).appendTo(r);
   }
   addValidationHandler(r, form, validationUrl, action.substring($("#hiddenContext").text().length));
}
// Deal with recaptchas which need to be dynamically generated on the client
function addAjaxRecaptcha(r, timerId, validationUrl, publicKey, theme, tabIndex, checkbox) {

   if (publicKey == null || publicKey == '') {
      createRobotCheckbox(r, timerId, checkbox);
      return;
   }
   r.each(function() {
      var 
         self = $(this),
         form = self.parents("form"),
         path = form.attr("action").substring($("#hiddenContext").text().length);
      if (self.data("bound") == null) {
         self.onShow(function() {
            function createAjaxRecaptcha() {
               self.children().remove();
               Recaptcha.create(publicKey,
                 self.attr("id"), {
                    theme: theme == null ? "blank" : theme,
                    tabindex: tabIndex == null ? 0 : tabIndex,
                    callback: function() {
                       addValidationHandler(self, form, validationUrl, path);
                    }
                 });
               // Disable the default behaviour when the user hits return within the recaptcha field
               var stopOnReturn = function(event) {
                   if (!event) var event = window.event;
                   if (event.keyCode == 13) {
                      event.cancelBubble = true;
                      if (event.stopPropagation) {
                         event.stopPropagation();
                      }
                      if (event.preventDefault) {
                         event.preventDefault();
                      }
                      return false;
                   }
                };
                self.get(0).addEventListener('keyup', stopOnReturn, true);
                self.get(0).addEventListener('keydown', stopOnReturn, true);
                self.get(0).addEventListener('keypress', stopOnReturn, true);
                self.get(0).addEventListener('change', stopOnReturn, true);
                if (timerId != null) {
                   $('<input type="hidden">').attr({
                       name: "timer_id",
                       value: timerId
                   }).appendTo(self);
                }
            };
            if (typeof Recaptcha != 'undefined') {
               createAjaxRecaptcha();
            } else {
               $.getScript("//www.google.com/recaptcha/api/js/recaptcha_ajax.js", function () {
                  createAjaxRecaptcha();
               });
            }
         });
      }
      self.data("bound", "true");
   });
}
function createRobotCheckbox(location, timerId, checkbox) {
   if (location.attr('recaptcha') == null) {
      location.children().remove();
      location.attr('recaptcha', 'true');
   }
   if (timerId != null && timerId != "") {
      if (checkbox == null) {
         checkbox = $("#i-am-not-a-robot");
      }
      $(checkbox.html().replace(/XXX/g, timerId).replace(/REQ/g, 'required').replace(/NAME/g, 'timer_id')).appendTo(location);
      var form = $(location.closest("form"));
      $.extend(form.validate().settings, {
         onfocusout: function(element) {
            if (!this.checkable(element)) {
              this.element(element);
            }
         }
      });
      $.extend(form.get(0), {
          checkRecaptcha: function(successCallback, failureCallback) {
             if (form.valid()) {
                successCallback();
             } else {
                failureCallback();
             }
          }
      });

      form.find(".required").each(function() {
         $(this).rules("add", {
            required: true,
               messages: {
                  required: $("#required_field").html()
              }
        });
     });
   }
}

function registerRuntimeRecaptchas() {
   var 
      r = $(".runtimeP2wRecaptcha"),
      timerId = $($("#timer_id", r).get(0)).text(),
      publicKey = $($("#recaptcha_publickey", r).get(0)).text(),
      theme = $($("#recaptcha_theme", r).get(0)).text(),
      tabIndex = $($("#recaptcha_tabindex", r).get(0)).text(),
      validationUrl = $("#hiddenContext").text() + "/recaptcha/validaterecaptcha.action";

   addAjaxRecaptcha(r, timerId, validationUrl, publicKey, theme, tabIndex);
}
//The final case is where we have to read the config from the server
function registerDynamicRecaptchas() {
   var 
      r = $("#dynamicP2wRecaptcha"),
      form = r.parents("form"),
      validationUrl = $("#hiddenContext").text() + "/recaptcha/validaterecaptcha.action",
      configurationUrl = $("#hiddenContext").text() + "/recaptcha/configurerecaptcha.action";
   if (r.length == 0) {
      return;
   }
   var path = form.attr("action").substring($("#hiddenContext").text().length);


   $.ajax({
      type: "POST",
      url: configurationUrl, 
      data: {
         "path": path
      },
      dataType: "html",
      success: function(response) {
         if (response) {
            addAjaxRecaptcha(r, $($("#timer_id", response).get(0)).text(), validationUrl,  $($("#recaptcha_publickey", response).get(0)).text(), $($("#recaptcha_theme", response).get(0)).text(), $($("#recaptcha_tabindex", response).get(0)).text(), $("#i-am-not-a-robot", response));
         }
      }
   });
}
$(document).ready(function() {
   registerStaticRecaptchas();
   registerRuntimeRecaptchas();
   registerDynamicRecaptchas();
});
