// Everything taken out of the global namespace...
var AIPApp = AIPApp || {
    timeout: 500,
    timeouts: [],
    closeTimer: 0,
    bookmarkMenuItem: "",
    broadcastCookie: "broadcast",
    consoleOK: (typeof console === undefined ? false : true),
    fades: {                                    // in milliseconds
        slow: 1000,
        medium: 750,
        fast: 500
    },
    maxAge: 60 * 60 * 24 * 365 * 2,             // 2 years (in seconds)
    regExp: {
        tags1: /<[^>]*>/g,
        tags2: /(<([^>]+)>)/gi,
        spaces: /  */g
    },
    /**
     * Close extra share options
     */
    bookmarkmenu_close: function() {
        if (this.bookmarkMenuItem) {
            this.bookmarkMenuItem.removeClass("showSoMe").addClass("hideSoMe");
        }
    },
    /**
     *  Called from template.jsp
     *  Adds no conflict class to dialog to override conflicting crossmark styles on our dialogs
     */
    dialogNoConflict: function(){
       if($('.ui-dialog').length > 0 || $('.ui-dialog').css('display') == 'block'){           
             $('.ui-dialog').each(function(){
             if(!$(this).hasClass('.crossmark-ui-dialog') && !$(this).hasClass('dialogConflict')){
                $(this).addClass('dialogConflict');
             }
             });
       }
    },
    /**
     * Create timer for extra share options
     */
    bookmarkmenu_timer: function() {
        this.closeTimer = window.setTimeout(this.bookmarkmenu_close, this.timeout);
    },
    /**
     * Cancel timer for extra share options
     */
    bookmarkmenu_canceltimer: function() {
        if (this.closeTimer) {
            window.clearTimeout(this.closeTimer);
            this.closeTimer = null;
        }
    },
    /**
     * Open extra share options
     */
    bookmarkmenu_open: function() {
        this.bookmarkmenu_canceltimer();
        this.bookmarkmenu_close();
        this.bookmarkMenuItem = $(this).find(".moreshareoptions").removeClass("hideSoMe").addClass("showSoMe");
    },
    /**
     * Display either a graph or a table
     *
     * @param {jQuery object} $dataTable    Table containing relevant data
     * @param {string}        graphType     Currently either 'line' or 'pie'
     * @param {string}        graphId       Element id
     * @param {string}        graphTitle
     * @param {string}        eMsg          Error messages
     */
    displayGraphOrTable: function($dataTable, graphType, graphId, graphTitle, eMsg) {
        var lineData = this.extractDataFromTable($dataTable);
        try {
            this.plotGraph(graphType, graphId, lineData);
        } catch (e) {
            if (this.consoleOK) {console.log(graphId + " failed with: " + e.message);}
            this.displayTabularMetrics(graphTitle, graphId, eMsg);
        }
    },
    /**
     * Extracts data from the table of data
     *
     * @param {jQuery object} table     Table containing relevant data
     */
    extractDataFromTable: function(table) {
        var lineData = [];
        table.find("tbody tr").each(function(index) {
            var $row = $(this),
                rowData = [];
            // APPEND the individual pieces of data
            // *** Be aware that we need to force the type of the count ***
            // *** otherwise jqplot fails...                            ***
            rowData.push($row.find(":nth-child(1)").text());
            rowData.push(+$row.find(":nth-child(2)").text());
            // PREPEND each set of data...
            lineData.unshift(rowData);
        });
        return lineData;
    },
    pendingPlots: [],
    /**
     * Plots graphs for metrics (pie and line only)
     *
     * @param {string} gtype graph type: pie|other (actually 'line')
     * @param {string} target id to which to attach output
     * @param {object} data data to graph
     */
    plotGraph: function(gType, target, data) {
        function canvasSupported() {
            var canvas = document.createElement('canvas');
            return (canvas.getContext && canvas.getContext('2d'));
        }
        // Because of crossmark we have to look in both places
        if ($ != jQuery) {
            jQuery = $;
        }
        if (typeof $.jqplot === "undefined") {
            AIPApp.pendingPlots.push({
                "gType": gType,
                "target": target,
                "data": data});
            if (AIPApp.pendingPlots.length == 1) {
                var url = canvasSupported() ? "/js/aip/jquery.jqplot.aip.js" : "/js/aip/jquery.jqplot.aip.ie8.js";
                $.ajax({
                    dataType: "script",
                    cache: true,
                    url: url,
                    success: function () {
                        for (var i = 0 ; i < AIPApp.pendingPlots.length ; i++) {
                            AIPApp.plotGraphWithJqplot($.jqplot, AIPApp.pendingPlots[i].gType, AIPApp.pendingPlots[i].target, AIPApp.pendingPlots[i].data);
                           
                        }
                        
                        
                    }
                });
            }
        } else {
            AIPApp.plotGraphWithJqplot($.jqplot, gType, target, data);
        }
    },
    /**
     * Plots graphs with jqplot for metrics (pie and line only)
     *
     * @param {object} jqplot itself
     * @param {string} gtype graph type: line|pie
     * @param {string} target id to which to attach output
     * @param {object} data data to graph
     */
    plotGraphWithJqplot: function(jqplot, gType, target, data) {
        var pieLabels = [],
            plotOptions = {},
            seriesColours = ["#1a6594", "#f0bd68", "#d6caa5"],
            total = 0,
            PLOT_MSG1 = "Unable to plot metrics: no HTML target given...";
        
        
         
     

        switch (gType) {
        case "pie":
            total = 0;
            $(data).map(function() {
                total += this[1];
            });
            pieLabels = $.makeArray($(data).map(function() {
                return this[0] + " (" + Math.round((this[1] * 100) / total) + "%)";
            }));

            plotOptions = { 
                // Define colours to use...
                seriesColors: seriesColours,
                // Define various overall defaults
                seriesDefaults: {
                    renderer: jqplot.PieRenderer,
                    rendererOptions: {
                        dataLabels: pieLabels,
                        dataLabelPositionFactor: 0.75,
                        highlightMouseDown: false,
                        highlightMouseOver: false,
                        showDataLabels: true,
                        sliceMargin: 10
                    }
                }
            };
            break;
             default:
                 // OK this is to get the max date we only want to plot up to the maximum date 
                 // since the data array is not ordered chronologically we have to do some Javascript work ....
                 var dateArray = [];
                 data.forEach( function(d) { 
                     var datePart = d[0];
                     //need to make a valid javascript date pattern 10/08/2015
                     datePart = datePart.substr(0, datePart.indexOf(' '));
                     datePart = datePart.split("-").join("/");
                     dateArray.push(new Date(datePart));
                   
                 }); 
                 
                 var maxDate=new Date(Math.max.apply(null,dateArray));
              
                 
            plotOptions = {
                // Define colours to use...
                seriesColors: seriesColours,
                // Define various other overall defaults
                seriesDefaults: {
                    shadow: false,
                    showMarker: false
                },
                // Define the defaults for both axes
                axesDefaults: {
                    tickRenderer: $.jqplot.CanvasAxisTickRenderer,
                    tickOptions: {
                        fontSize: "10pt"
                    }
                },
                // Define specific properties for the X axis
                // tickInterval = 60 * 60 * 24 * 30 * 1000
                // (milliseconds in 30 days)...
                axes: {
                    xaxis: {
                        renderer: jqplot.DateAxisRenderer,
                        pad: 0,
                        max: maxDate,
                        tickOptions: {
                            angle: -90,
                            formatString: "%b - %Y  "
                        }
                        
                    },
                    yaxis: {
                        min: 0,
                        tickOptions: {
                            formatString: "%7d  "
                        }
                    }
                },
                highlighter: {
                    show: true,
                    sizeAdjust: 10
                },
                cursor: {
                    show: false
                }
            };
            break;
        }
        if (target) {
            var plot = jqplot(target, [data], plotOptions);
            
            $(window).resize(function() {
                plot.replot( { resetAxes: true } );
                });
        } else {
            alert(PLOT_MSG1);
        }
    },
    /**
     * Display metrics data as a table (normally following a failure with plotting)
     *
     * @param {string}  tableName
     * @param {string}  graphName
     * @param {string}  eMsg
     */
    displayTabularMetrics: function(tableName, graphName, eMsg) {
        var currTable = $("#" + tableName);
        currTable.before(eMsg);
        currTable.find("tbody .metricDate").each(function(index) {
            var currItem = $(this),
                dateStr = currItem.text(),
                mDate = new Date(dateStr.substr(0, 10));
            currItem.text(mDate.toDateString());
        });
        currTable.find(".metricDate, .totalCount").addClass("metricsErrorDesc");
        currTable.find(".metricCount").addClass("metricsErrorCount");
        currTable.addClass("metricsErrorTable");
        $("#" + graphName).addClass("hideMe");
    },
    /**
     * Handles the chevron interaction
     *
     * @param {jQuery object} $here         Current location
     */
    handleChevrons: function($here) {

        if ($here.hasClass("down")) {
			var $foundChevron = this.findChevronContent($here);
			$foundChevron.removeClass("hidden"); // KLOC : this remained hidden, so slideup / down was not shown on RWD version, so removed it here.
            $foundChevron.slideDown();
            this.changeChevronDirection($here, "down");
        } else if ($here.hasClass("up")) {
            this.findChevronContent($here).slideUp();
            this.changeChevronDirection($here, "up");
        }
    },
    /**
     * Changes the direction of the chevrons
     *
     * @param {jQuery object} $here         Current location
     * @param {string}        direction     Direction of arrow (down | up)
     */
    changeChevronDirection: function($here, direction) {
        if (direction === "down") {
            $here.removeClass("down").addClass("up").find("img").attr("src", "/images/aip/chevron_up.gif");
        } else if (direction === "up") {
            $here.removeClass("up").addClass("down").find("img").attr("src", "/images/aip/chevron_down.gif");
        }
    },
    /**
     * Find any content associated with the chevron
     *
     * @param {object}   jQuery context
     */
    findChevronContent: function(context) {
        return context.siblings(".chevroncontent").add(context.parent().siblings(".chevroncontent"));
    },
    /**
     * Define some 'standard' options for a dialog box...
     */
    //stdDialogOptions: {
    //    autoOpen : false,
    //    height : 640,
    //    width : 480,
    //    modal : true,
    //    resizable : true,
    //    position : {
    //        my : "center",
    //        at : "center",
    //        of : $(window)
    //    }
    //},
    /**
     * Insert DeepDyve link
     *
     * @param {string} type             The type of link (button | text)
     * @param {object} $insertionPoint  jQuery object to which to attach the link
     */
    insertDeepDyveLink: function($insertionPoint) {
        var currencySymbol = "$",
            DDoi = "",
            DDUrl = "http://www.deepdyve.com/rental-link?fieldName=journal_doi&docId=";
            newHtml = "",
            deepdyveprice = "",
            accessoptionsDiv = $insertionPoint;

        if ($insertionPoint && typeof $insertionPoint === "object") {
            DDoi = $insertionPoint.find(".deepdyve").text();
            
            if (DDoi) {
                DDUrl += DDoi
                DDUrl += "&key=AIP&affiliateId=AIP&format=jsonp&callback=?";
                
                $.getJSON(DDUrl, function(data) {
                    if (data.status === "ok") {
                        deepdyveprice = currencySymbol + data.price;
                        
                        //replace href and insert price
                        $insertionPoint.find("a").attr("href", data.url);
                        $insertionPoint.find(".deepdyveprice").html(deepdyveprice);
                    	//unhide div
                        $insertionPoint.removeClass("hidden");
                    }
                });
            }
        }
    },
    /**
     * Add event logging any PDFs within the location
     * @param location the part of the DOM where PDF download links can be found
     */
    addPdfMessageLogging: function(location) {
        location.find(".pdf a").click(function(e) {
           if (_gaq) {
               _gaq.push(['_trackEvent', 'Download', 'PDF', this.href]);
           }
        });
    },
    /**
     * Creates link to DeepDyve (for all instances)
     *
     * @param {string}  type    The type of link (button | text)
     */
    createDeepDyve: function() {
        $(".rent-link-text").each(function(index) {
            var insertionPoint = $(this);
            AIPApp.insertDeepDyveLink(insertionPoint);
        });
    },
    /**
     * Sends a siq tagging request
     *
     * @param {url}         SIQ url
     * @param {string}      Item Id
     * @param {string}      Page title
     * @param {string}      Item DOI
     * @param {string}      Event type
     * @param {boolean}     Log PT event
     * @param {string}      Search term
     * @param {function}    Callback function name (optional)
     */
    siq: function(siqUrl, webId, pageTitle, doi, eventType, logPub2webEvent, searchTerm, callback) {
        //if (AIPApp.consoleOK) {console.info("siq(): " + "\n url: " + siqUrl + "\n webId: " + webId + "\n title: " + pageTitle + "\n DOI: " + doi +  "\n type: " + eventType + "\n log: " + logPub2webEvent + "\n search term: " + searchTerm + "\n callback: " + callback);}
        if (!searchTerm) {
            searchTerm = "";
        }
        // Pending items should not have any pub2web events logged
        if ($("#isPending").length > 0) {
            logPub2webEvent = 'false';
        }
        var data = {
            itemId : webId,
            pageTitle : pageTitle,
            doi : doi,
            eventType : eventType,
            logPub2webEvent : logPub2webEvent,
            searchTerm : searchTerm
        };
        // A load is required rather than get for the script element to be run by  the browser - similarly no suffixed selector is permitted
        $("#siqResponse").load(siqUrl, data, function(contents) {
            if (callback) {
                callback(contents);
            }
        });
    },
    /**
     * Chop up a url into parameters...
     *
     * @param {string}  _url
     */
    getUrlVars: function(_url) {
        var vars = [], i, hash, hashes;
        if (_url) {
            hashes = _url.slice(_url.indexOf('?') + 1).split('&');
            for (i = 0; i < hashes.length; i++) {
                hash = hashes[i].split('=');
                vars.push(hash[0]);
                vars[hash[0]] = hash[1];
            }
        }
        return vars;
    },
    /**
     * Checks for the appearance of the MORE links in Related tab...
     */
    checkRelatedTabChange: function() {
        var len = 0,
            loop = 0,
            moreLinkHtml = "",
            $target;

        $target = $("#morelikethis").find(".morelink");
        moreLinkHtml += "<a href='#' title='' class='more std-display'><img src='/images/aip/plus_icon.gif' alt='+' /> More</a>";
        moreLinkHtml += "<a href='#' title='' class='less std-display hidden'><img src='/images/aip/minus_icon.gif' alt='-' /> Less</a>";
        if ($target.length) {
            for (loop = 0, len = AIPApp.timeouts.length; loop < len; loop++) {
                window.clearTimeout(loop);
            }
            $target.html(moreLinkHtml);
        } else {
            // call the function again after default milliseconds (with context)
            AIPApp.timeouts.push(setTimeout(AIPApp.checkRelatedTabChange, AIPApp.timeout));
        }
    },
    /**
     * Displays small dialog box with variable heading and text
     *
     * @param {event object}    Event object
     * @param {string}          Heading
     * @param {string}          Anchor
     * @param {string}          (Short) text message to display
     * @param {string}          Width of dialog box (optional)
     * @param {string}          Height of dialog box (optional)
     * @param {string}          my position (optional)
     * @param {string}          at position (optional)
     * @param {string}			include Don't show again & related cookies, string is unique id (optional)
     * @param {string}			text for a Close button, only shows if this is set  (optional)
     * @param {string}			URL for destination of button, if null will close dialog
     */
    displaySmallDialog: function(e, anchor, heading, text, width, height, myPos, atPos, inclDSAid, inclCBtnText, inclCBtnLink) {
        var $this = $(e.target),
            $dialogHook = $(anchor),
            dWidth = width || 200,
            dHeight = height || 125,
            dMyPos = myPos || "left top",
            dAtPos = atPos || "left bottom",
            userName = encodeURI($('.signedinas + .signedinas').text());
        e.preventDefault();
        if ($dialogHook.length && (inclDSAid == null || (inclDSAid !== null && !libCookies.hasCookie(inclDSAid+userName)))) {
            $dialogHook.dialog({
                autoOpen : false,
                height : dHeight,
                modal : false,
                position: {
                    my: dMyPos,
                    at: dAtPos,
                    of: $this
                },
                resizable : true,
                width : dWidth
            });
            
            $dialogHook.find(".dialogText").remove();

            $dialogHook.dialog().parent(".ui-dialog").wrap("<div class=\"signInOrRegisterWrapper\"></div>");
            
        	$dialogHook.dialog("open");

            if (heading) {
                $dialogHook.append("<h2 class=\"dialogText\">" + heading + "</h2>");
            }
            if (text) {
                $dialogHook.append("<span class=\"dialogText\">" + text + "</span>");
            }
            if (inclDSAid) {
            	$dialogHook.append("<br/><input id=\"dontShowAgain\" class=\"dialogText dontShowAgain\" type=\"checkbox\" id=\""+inclDSAid+"\" checked /> <label class=\"dialogText\" for=\"dontShowAgain\">Don't show again.</label>");
            	//if checkbox shown, close button is req
            	$dialogHook.append("<button class=\"dialogText dontShowAgain dialog-close\">Close</button>");
            	$('button.dontShowAgain').click(function(e){
            		if( $('input.dontShowAgain').prop('checked') ){
            			libCookies.setCookie(inclDSAid+userName, inclDSAid, 'Fri, 31 Dec 9999 23:59:59 GMT')
            		}
            	});
            	
            }
            if (inclCBtnText && !inclCBtnLink) {
            	$dialogHook.append("<span class=\"dialogText\"><br/><button class=\"dialog-close\">" + inclCBtnText + "</button></span>");
            } else if (inclCBtnText && inclCBtnLink) {
            	$dialogHook.append("<span class=\"dialogText\"><br/><a href=\""+inclCBtnLink+"\"><button >" + inclCBtnText + "</button></a></span>");
            }
            
            //only applies when Close button present
            $('.dialog-close').click(function(){
        		$dialogHook.dialog("close");
        	});
        }
    },
    /**
     * As the name suggests...sorts the results in date order (NEWest | OLDest)
     * For non-ajax sorting (see searchresults-ahah.js to retrieve sort via ajax)
     * 
     * @param {jQuery object} jQuery event
     * @param {string}        NEW|OLD
     */
    sortByDate: function(e, dateDirection) {
        var inputVal = (dateDirection === "NEW" ? "true" : "false"),
            sortForm = $("#sortForm");
        e.preventDefault();
        if (sortForm.find("input[name=sortDescending]").length === 0) {
            sortForm.append("<input type='hidden' name='sortDescending' value='" + inputVal + "' />");
        } else {
            sortForm.find("input[name=sortDescending]").val(inputVal);
        }
        sortForm.append("<input type='hidden' name='sortField' value='prism_publicationDate' />");
        sortForm.submit();
    },
    /**
     * Simple function to display a larger image when the user clicks on the magnifying glass
     *
     * @param e
     */
    magnifyImage: function(e) {
        var dHeight = $(window).height() * 0.9,
            dWidth = dHeight * 0.70,
            dTitle = "Issue cover",
            coverImagePdf = $("#coverImagePdf").text(),
            pdfPopErrorMessage = $("#pdfPopErrorMessage").text(),
            $coverImageDialog = $(".coverImageDialog");

        e.preventDefault();

        // IE8 likes to believe it is caching a PDF without actually doing it
        if ($.browser.msie && $.browser.version === "8.0") {
            coverImagePdf += "?rnd=" + Math.random() + ".pdf";
        }

        if ($($coverImageDialog).hasClass('ui-dialog-content')) {
            $coverImageDialog.dialog("destroy");
        }
        $coverImageDialog.dialog(AIPApp.stdDialogOptions).dialog({title: dTitle, height: dHeight, width: dWidth});
        $coverImageDialog.find("#pdfObject").remove();
        // $coverImageDialog.append("<div id='pdfObject'><object data='" + coverImagePdf + "' title='Issue cover' height='" + (dHeight * 0.9) + "' width='" + (dWidth * 0.9) + "' /></div>");
        $coverImageDialog.append("<div id='pdfObject'><object data='" + coverImagePdf + "' title='Issue cover' height='" + (dHeight * 0.9) + "' width='" + (dWidth * 0.9) + "'><div class='not-supported-pdf'><h4>Plugin Not Supported</h4> <br /><a href='"+ coverImagePdf +"'>" + pdfPopErrorMessage + "</a></span></object></div>");
        $coverImageDialog.dialog("open");
    },
    /**
     * Generic unescape routine
     *
     * @param string
     */
    unescapeHTML: function(str) {
        return str.replace(/&amp;/g, "&")
                  .replace(/&lt;/g, "<")
                  .replace(/&gt;/g, ">");
    },
    /**
     * Generic ampersand replacement
     *
     * @param context   jQuery object containing context
     */
    replaceAmps: function(context) {
        var oldText = context.text();
        if (oldText.indexOf("&amp;") !== -1) {
            context.text(oldText.replace(/&amp;/g, "&"));
        }
    },
    /**
     * Specialised replacement of ampersands in facets...
     *
     * @param index     Index object
     */
    replaceAmpsInFacets: function(index) {
        var $this = $(this).find("a span").eq(0);
        if ($this.length) {
            AIPApp.replaceAmps($this);
        }
    },
    /**
     * Specialised replacement of ampersands in text descriptions...
     *
     * @param e     Event object
     */
    replaceAmpsInDesc: function(e) {
        var $this = $(e.target).find(".description");
        if ($this.length) {
            AIPApp.replaceAmps($this);
        }
    },
    /**
     * This function creates a new anchor element and uses location properties (inherent) to get 
     * the desired URL data. Some String operations are used (to normalize results across browsers).
     * 
     * @param {string} url (well-formed)
     * 
     * @author http://james.padolsey.com/javascript/parsing-urls-with-the-dom/
     */
    parseUrl: function(url) {
        var a =  document.createElement('a');
        a.href = url;
        return {
            source: url,
            protocol: a.protocol.replace(':',''),
            host: a.hostname,
            port: a.port,
            query: a.search,
            params: (function() {
                var ret = {},
                    seg = a.search.replace(/^\?/,'').split('&'),
                    len = seg.length,
                    i,
                    s;
                for (i = 0; i < len; i++) {
                    if (!seg[i]) { continue; }
                        s = seg[i].split('=');
                        ret[decodeURIComponent(s[0])] = decodeURIComponent(s[1]);
                    }
                    return ret;
                })(),
            file: (a.pathname.match(/\/([^\/?#]+)$/i) || [,''])[1],
            hash: a.hash.replace('#',''),
            path: a.pathname.replace(/^([^\/])/,'/$1'),
            relative: (a.href.match(/tps?:\/\/[^\/]+(.+)/) || [,''])[1],
            segments: a.pathname.replace(/^\//,'').split('/')
        };
    },
    /* The code below picks up the ads from #realmediaAdCode iframe
     * and moves the generated HTML into its respective place in the page template */
        advertsLoaded: function() {
        var $realmediaAdCode = $("#realmediaAdCode");
        if ($realmediaAdCode.length) {
            $realmediaAdCode.load(function(){
                try {
                    var ads = $realmediaAdCode.contents().find(".AD_OAS");
                    ads.each(function(index) {
                        var $this = $(this),
                            adIdentifier = $this.data("adidentifier"),
                            $targetA = $this.nextAll("a"),
                            $targetO = $this.nextAll("object"),
                            adElementToAppend = "",
                            $target,
                            copyAd;
        
                        adElementToAppend = "#OAS_" + adIdentifier;
        
                        $target = $targetA.length ?$targetA : $targetO;
                        $target.appendTo(adElementToAppend);
                        
                        // If there are no adverts then there should be no gap
                        if ($target.html() != null && $target.html().indexOf("empty.gif") == -1 && $target.html() != '') {
                        	  $(adElementToAppend).show();
                        }
                        
		              	  $(".advert").each(function(){
		            		  if ($(this).html() == '' || $(this).html() === undefined || $(this).html().indexOf("empty.gif") > -1){
		            			  $(this).hide();
		            		  }
		            	  });
	                  	  
                        
                    });
                    
                } catch (ignoreAccessDeniedErrors) {
                }
            });
        }
    },
    /**
     *  To fix RSS feeds with headings in them
     *  
     *  @param {string}        Cookie name
     *  */
    encodeHeadingForRss: function (headingSelector) {
    	$(headingSelector).each(function(){
    		var $t = $(this),
    			headingText = $t.text(),
    		rssHref =  $t.parent().find('.rssicon a').attr('href');
    		//replace occurence of heading inside URL with encoded version if found
    		rssHref = rssHref.replace(headingText, escape(headingText));
    		//console.log(rssHref+' headingtxt: '+headingText);
    		//apply new href
    		$t.parent().find('.rssicon a').attr('href', rssHref);
    	});
    },
    /**
     * Changes more or less, first type
     * 
     * @param {event}        Click event
     * @param {string}       Selector 1
     * @param {string}       Selector 2
     * 
     *  */
    flipMoreLess: function(evt, selector1, selector2) {
        var $here = $(evt.target);
        evt.stopImmediatePropagation();
        evt.preventDefault();
        if ($here.hasClass("moreLink")) {
            $here.siblings(selector1).find(selector2).show();
            $here.hide();
            $here.siblings(".lessLink").show();
        }
        if ($here.hasClass("lessLink")) {
            $here.siblings(selector1).find(selector2).hide();
            $here.hide();
            $here.siblings(".moreLink").show();
        }
    },
    /**
     * Changes more or less, second type
     * 
     * @param {event}        Click event
     * @param {string}       Selector 1
     * @param {string}       Selector 2
     * 
     *  */
    flipMoreLess2: function (evt, selector1, selector2) {
        var $here = $(evt.target);
        evt.stopImmediatePropagation();
        evt.preventDefault();
        if ($here.hasClass("moreLink2")) {
            $here.parent().siblings(selector1).find(selector2).show();
            $here.hide();
            $here.siblings(".lessLink2").show();
        }
        if ($here.hasClass("lessLink2")) {
            $here.parent().siblings(selector1).find(selector2).hide();
            $here.hide();
            $here.siblings(".moreLink2").show();
        }
    },
    
    /**
     * Sort out a cookie and close the popup...
     */
    clearPopup: function() {
        var maxAge = 60 * 60 * 24 * 365 * 2,
            path = "/",
            $popup = $(this).closest(".broadcastMessagePopUp"),
            cookieValue = $popup.attr("data-value") ? $popup.attr("data-value") : "n";
        if ($popup.hasClass("settingP")) {
            libCookies.setCookie(AIPApp.broadcastCookie, cookieValue, maxAge, path);
        } else {
            libCookies.setCookie(AIPApp.broadcastCookie, cookieValue, null, path);
        }
        $popup.fadeOut(AIPApp.fades.slow);
    },
    /**
     * Default term gray text by case
     */
    defaultSearchTerm: "Search Scitation",
    defaultSearchTermWithinOption: "Search",
    defaultAdvSearchTerm: "Enter Keywords/Phrases",
    defaultRefineTerm: "Refine your search",
    defaultTopicSearchTerm: "Search within topics",
    searchBoxArray: ["#quickSearchBox", "#advanced-search-form #value1", "#searchRefineBox", "#topicSearchBox"],
    defaultFocusAndBlur: function(inputId){
    	var checkTerm;
    	switch( inputId ) {
			case '#quickSearchBox' :
				checkTerm = $('#searchBox').hasClass('withinPub') ? AIPApp.defaultSearchTermWithinOption : AIPApp.defaultSearchTerm;
				break;
			case '#searchRefineBox' :
				checkTerm = AIPApp.defaultRefineTerm;
				break;
			case '#advanced-search-form #value1' :
				checkTerm = AIPApp.defaultAdvSearchTerm;
				break;
			case '#topicSearchBox' :
				checkTerm = AIPApp.defaultTopicSearchTerm;
				break;
			default:
				return false;
    	}

    	// when you click into box remove default text
        $(inputId).focus(function() {
            // Check val for search text
            var $searchField = $(this);

            if ($searchField.val() ===  checkTerm || $searchField.val() === '') {
                $searchField.val("");
                $(inputId).removeClass("defaultTerm");
            }
        // add the default text back in if they click out without entering anything
        }).blur(function() {
            // Check val for search text
            var $searchField = $(this);
            
            // Check for empty input
            if ($searchField.val() === "") {
                $(inputId).addClass("defaultTerm");
                $searchField.val(checkTerm);
            }
        });
    },
    responsiveAdverts:function(){ 

			var cacheAdverts = false;
		    var currentBreakPoint = $("#OAS_MobileBanners").text();
			var currentBreakPointTab = $("#OAS_TableBanners").text();
			var currentBreakPointDesktop = $("#OAS_DesktopBanners").text();
			// trim last ',' of list 
			currentBreakPoint = currentBreakPoint.substring(0,currentBreakPoint.length -1);
			currentBreakPointTab = currentBreakPointTab.substring(0,currentBreakPointTab.length -1);
			currentBreakPointDesktop = currentBreakPointDesktop.substring(0,currentBreakPointDesktop.length -1);
							
			// set breakPoint advert calls to false
			var desktopAdvertscalled = false, tabletAdvertscalled = false, moblieAdvertscalled = false;
			//var Urlpt1 = $("#hiddenContext").text() + '/content/realmedia?fmt=${_fmt}&adPositionList=';
			var Urlpt1 = $("#hiddenContext").text() + $(".Urlpt1").text();
	   		//var Urlpt2 = '&advertTargetUrl=${_advertTargetUrl}&sitePageValue=${_sitePageValue}&pageURL=${_pageURL}';
	   		var Urlpt2 = $(".Urlpt2").text();
	   		
		   
			// check if banner from different break point has been shown before, and dont empty containers and keep it cached in page
	   		function cachedBanners(banners){
	   			var cacheAdverts, bannersArray = banners.split(",");
	   			$.each(bannersArray, function(index, value){
					 if ($("#OAS_" + value + " a").length == 1) {
						 cacheAdverts = true;
					 }
				});
	   			return cacheAdverts;
	   		}
	   		// function to call the required banners in view iframe.
	   		function changeBreakPointAdverts(currentBreakNew){
					if(currentBreakNew != ""){
						document.getElementById("realmediaAdCode").src = encodeURI(Urlpt1 + currentBreakNew + Urlpt2);
					}
			}
			
			$(window).bind("load resize", function(){
				var windowWidth = $(window).width();				
				if (windowWidth >= 992 && !desktopAdvertscalled){
					cacheAdverts = 	cachedBanners(currentBreakPointDesktop);
					
					if (!cacheAdverts) {
					   changeBreakPointAdverts(currentBreakPointDesktop);
					   desktopAdvertscalled = true; tabletAdvertscalled = false; moblieAdvertscalled = false;
					}
				}else if (windowWidth <= 991 && windowWidth >= 768 && !tabletAdvertscalled){
					cacheAdverts = 	cachedBanners(currentBreakPointTab);	
				
					if (!cacheAdverts) {
						changeBreakPointAdverts(currentBreakPointTab);	
						desktopAdvertscalled = false; tabletAdvertscalled = true; moblieAdvertscalled = false;
					}
				}else if (windowWidth <= 767 && !moblieAdvertscalled){
					cacheAdverts = 	cachedBanners(currentBreakPoint);
					if (!cacheAdverts) {
						changeBreakPointAdverts(currentBreakPoint);	
						desktopAdvertscalled = false; tabletAdvertscalled = false; moblieAdvertscalled = true;
					}
				} 					
			});
		  } 
 	   
};

/**
 * Loads a JavaScript script from the cache, if available
 */
jQuery.cachedScript = function(url, options) {
    // allow user to set any option except for dataType, cache, and url
    options = $.extend(options || {}, {
        dataType : "script",
        cache : true,
        url : url
    });
    // Use $.ajax() since it is more flexible than $.getScript
    // Return the jqXHR object so we can chain callbacks
    return jQuery.ajax(options);
};


// ONLOAD ACTIONS
$(document).ready(function() {
	
	if ($("#newsrss").text() == 'true') {			
		var newsRssTabLink = $("#newsRssTabLink").text(),
		newsRssItemCount = $("#newsRssItemCount").text(),
		loadRssNewsItemsUrl = $("#hiddenContext").text() + "/loadnewsitems/newsrss?src=" + newsRssTabLink + "&num=" + newsRssItemCount;
		
		$(".aboutContainer").append('<div class="moreitemsloadingwrappper"><img class="morePostsLoading" src="/images/jp/spinner.gif" alt="Loading items" /></div>');
		
		$.ajax({
			type: "GET",
			url: loadRssNewsItemsUrl,
			success: function(resp, statusText, req) {
				$(".aboutContainer").append(resp);				
			},
			error: function(resp, statusText, req) {
				$(".aboutContainer").append("Sorry there is some problem in accessing the news feed");				
			},
			complete: function(req, statusText) {
				$(".moreitemsloadingwrappper").remove();
				$('.aboutContainer a').each(function(index){
					var currentLink = $(this); 
					currentLink.attr('class', 'aip-user-externallink aip-externallink-icon');
				});
			}
		});
	}
	
	// call new responsive banners
	AIPApp.responsiveAdverts();
   
	// a-z filter option for smaller screens
    $( ".select_a_to_z_mobile" ).change(function() {
        var url = $(this).find(':selected').data('url');
        window.location.href = url;
    });
    var hiddenContext = $("#hiddenContext").text(),
        appUrls = {
            "autosuggest":      hiddenContext + "/search/autosuggest",
            "citations":        hiddenContext + "/content/citations",
            "commentcount1":    hiddenContext + "/commenting/comments/commentscount.action",
            "commentcount2":    hiddenContext + "/commenting/comments/jsoncommentscount.action",
            "metrics":          hiddenContext + "/metrics/metrics.action",
            "morelikethis":     hiddenContext + "/search/morelikethis",
            "search":           hiddenContext + "/search",
            "searchahah":       hiddenContext + "/search/ahahsearch.action",
            "siq":              hiddenContext + "/siq/siq.action",
            "statslogredirect": hiddenContext + "/statslogredirect",
            "statslogwrapper":  hiddenContext + "/statslogwrapper",
            "gatheritems":      hiddenContext + "/collections/gatherItems"
        },
        winProps0 = "location=no,toolbar=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes",
        winProps1 = winProps0 + ",width=700,height=600",    // RightsLink window
        winProps2 = winProps0 + ",width=1024,height=600";   // T&C window

    
	if (aipProps.journalType === "searchJournal" && aipProps.currentPage === "journal.journal_tab") {
    		$(".item-rssFeed").hide();
    	}	

	if (aipProps.currentPage === "journal.articles") {
		$(".paginator > a").each(function(index) {
			var href = $(this).attr("href");
			if ((href).indexOf("journal=") == -1) {
				href = href + "&journal=" + aipProps.journalCode;
				$(this).attr("href", href);
			}
		});
		$(".perpageoptions > a").each(function(index) {
			var href = $(this).attr("href");
			if ((href).indexOf("journal=") == -1) {
				href = href + "&journal=" + aipProps.journalCode;
				$(this).attr("href", href);
			}
		});
	}
	//bug 60265
	$(".paginator > a").each(function(index) {
		var href = $(this).attr("href");
		var facetNames = $("#facetedbrowseform #facetnames").val();
		var facetValues = $("#facetedbrowseform #facetvalues").val();
		if ((facetNames !== undefined) && (facetValues !== undefined)) {
			var actionUrl = $("#facetedbrowseform").attr("action");			
			if (href.indexOf("facetnames") == -1 && facetNames != "") {					
				href = href + "&facetnames=" + facetNames;
				href = href + "&facetvalues=" + facetValues;
				$(this).attr("href", href);
			}
		}
	});
	
	$(".perpageoptions > a").each(function(index) {
		var href = $(this).attr("href");
		var facetNames = $("#facetedbrowseform #facetnames").val();
		var facetValues = $("#facetedbrowseform #facetvalues").val();
		if ((facetNames !== undefined) && (facetValues !== undefined)) {
			var actionUrl = $("#facetedbrowseform").attr("action");			
			if (href.indexOf("facetnames") == -1 && facetNames != "") {					
				href = href + "&facetnames=" + facetNames;
				href = href + "&facetvalues=" + facetValues;
				$(this).attr("href", href);
			}
		}
	});

    
    // Display any broadcast news...
    $(".broadcastMessagePopUp").each(function(index) {
        // Grab the cookies...
        var bcCookie = libCookies.getCookie(AIPApp.broadcastCookie),
            displayBroadcastMessage = true,
            $popup = $(this),
            cookieValue = $popup.attr("data-value") ? $popup.attr("data-value") : "n";;
        if (bcCookie && bcCookie === cookieValue) {
            displayBroadcastMessage = false;
        }
        if (displayBroadcastMessage) {
            $(this).fadeIn(AIPApp.fades.slow);
        }
    });

    $(".broadcastMessagePopUp a.surveyLink").click(AIPApp.clearPopup);

    $(".closeBroadcastMessagePopup").click(AIPApp.clearPopup);

    // Create a deepdyve article rent link if it is necessary
    if (($(".deepdyve").length > 0) && ($(".rentItem").length === 0)) {
    	AIPApp.createDeepDyve();
    }

    // Custom web form Tokens added on submit
    $("#customwebform").submit(function(e) {
    	e.preventDefault();
        e.stopImmediatePropagation();
        var submitFunction = function() {  
	        var token = $("#cFGeneratedToken").text(),
	        text = $("#cFTokenString").text(),
	        tokenCF = $("<input>").attr({"type" : "hidden", "name" : "hashText","id" : "hashText"}).val(text),
	        tokenTextCF = $("<input>").attr({"type" : "hidden", "name" : "hashToken", "id" : "hashToken" }).val(token),
	        $webForm = $("#customwebform");
	        $webForm.append($(tokenCF));
	        $webForm.append($(tokenTextCF));
	        customwebform.submit();
        };
        if (this.checkRecaptcha) {
            this.checkRecaptcha(submitFunction);
        } else if ($(this).valid()) {
            submitFunction();
        }	        
    });

    // Custom web form validation
    if (validateForm) {
        validateForm($("#customwebform"));
    }

    // Replace all broken images with placeholder images
    /*$("img.cover").error(function() {
        $(this).unbind("error").attr("src", "/images/aip/placeholder-image.jpg");
    });*/
    $("img.urlnotprovided").attr("src", "/images/aip/placeholder-image.jpg");

    /*Share Options - More box show*/
    $(".viewfurthershareoptions").hover(
        AIPApp.bookmarkmenu_open,
        AIPApp.bookmarkmenu_timer
    );
    $(".viewfurthershareoptions img").click(AIPApp.bookmarkmenu_open);

    // Send the user to the signin...
    $(document).on("click", ".institutionalusermsg .signinlink", function(e) {
        $(".item-signin .signinlink").trigger("click");
    });

    /*Chevron functionality click  handler */
    $(document).on("click", ".chevron", function(e) {
        var $this = $(this);
        e.preventDefault();
        AIPApp.handleChevrons($this);
        if ($this.hasClass("signinlink")) {
            $("#signname").focus();
        }
    });

	/* signin icon flip handler */
	$('.signinlink').click(function(){
		var icon = $(this).parent().find('.signinicon');	
		if (icon.hasClass("aip-icon-circle-right4")){
			icon.removeClass("aip-icon-circle-right4");
			icon.addClass("aip-icon-circle-down4");
		} else {
			icon.removeClass("aip-icon-circle-down4");
			icon.addClass("aip-icon-circle-right4");
		}
		/*if(AIPApp.consoleOK){
			console.log("This works");
		}*/
	});
    // adding to support focus visibility for sign in box
    $("#signinform").find("input[type='text'], #signinform input[type='password']")
        .focus(function() {
            $(this).removeClass("pwbox-normal").addClass("pwbox-highlight");
        })
        .blur(function() {
            $(this).removeClass("pwbox-highlight").addClass("pwbox-normal");
        });

    /*click handler for export button*/
    $("#exportbutton").click(function(e) {
        var anchor = $("#exportselect");
        e.preventDefault();
        if (anchor.val()) {
            window.location = anchor.val();
        }
    });

    /* for 'reprints & permissions' link in the sidebar
     * Use a pop-up window rather than a full window... 
     */
    $(".item-reprint a.popup").click(function(e) {
        e.preventDefault();
        window.open((this.href + "?url=" + window.location.href), "RightsLink", winProps1);
    });

    //authors popup
    $(document).on("click", ".authorsWithPopup span.meta-value.authors a", function(e) {
        e.preventDefault();
        var $here = $(this),
            $dialog = $("#authorpopup"),
            $target = $here.closest(".authorsWithPopup"),
            authorName = $here.text(),
            authorNamePrefix = "",
            authorNameSuffix = "",
            authorNameForPubMedSearch = authorName,
            dHeight = 170,
            dWidth = 200,
            linkPattern,
            newLink,
            offset = 50,
            popuptext = "",
            posX = 0,
            posY = 0,
            title = "",
            tmpArray = [],
            scitationLink = $target.siblings(".scitationSearch").html(),
            pubmedLink = $target.siblings(".pubmedSearch").html(),
            scholarLink = $target.siblings(".scholarSearch").html();

        $(".authorpopupwrapper").remove();
        $dialog.find(".popuptext").remove();
        scitationLink = scitationLink.replace("##AUTHORLINK##", $here.attr("href"));
        pubmedLink    = pubmedLink.replace("##AUTHORNAME##", authorNameForPubMedSearch);
        scholarLink   = scholarLink.replace("##AUTHORNAME##", authorName).replace(/&amp;amp;quot;/g, "&quot;");

        if ($here.hasClass("nonDisambigAuthorLink")) {
            linkPattern = /(.*)href="([^"]*)"(.*)/;
            tmpArray = scitationLink.match(linkPattern);
            if (tmpArray !== null) {
                newLink = tmpArray[1] + 'href="' + tmpArray[2] + '"' + tmpArray[3];
            }
            scitationLink = newLink;
        }
        if (authorName.indexOf(". ") > 0) {
            // Bug 37062 - Pubmed search has data loaded differently to the Pub2web.
            // The results come back more reliably if we put the Initials at the end of the last name.
            authorNamePrefix = authorName;
            authorNamePrefix = authorNamePrefix.substring(0, authorNamePrefix.indexOf(". "));

            authorNameSuffix = authorName.substring(authorName.indexOf(". ") + 2);
            authorNameForPubMedSearch = authorNamePrefix + " " + authorNameSuffix;
        }
        popuptext = "<div class=\"popuptext\">" +
                    "<div class=\"popup-link\">" + scitationLink + "</div>" +
                    "<div class=\"popup-link\">" + pubmedLink + "</div>" +
                    "<div class=\"popup-link popup-link-last\">" + scholarLink + "</div>" +
                    "</div>";

        title = "<div class=\"popup-header\">More content by<br/><div class=\"authorname-in-popup\">" + authorName + "</div></div>";
        posX = $here.offset().left - $(document).scrollLeft() - offset + $here.outerWidth();
        posY = $here.offset().top  - $(document).scrollTop()  + $here.outerHeight();

        $dialog.dialog({
            autoOpen: false,
            height: dHeight,
            modal: false,
            position: [posX, posY],
            title: title,
            width: dWidth
        });
        $dialog.dialog().parent(".ui-dialog").wrap("<div class='authorpopupwrapper'></div>");

        $dialog.dialog("open");
        $dialog.append(popuptext);
    });
    
    // Click handler for .addAlertLink (only shown to auth users)
    $(".addAlertLink").one('click', function(e){
        var source = e.target;
        // To propagate the event in case of blurb-editor image is clicked
        if ($(source).is("img")) {
            return true;
        }
        e.preventDefault();
        var $parent = $(this).closest("li"),
            alertContext = $parent.find(".alertContext").text(),
            alertContextTitle = $parent.find(".alertContextTitle").text(),
            alertContentId = $parent.find(".alertContentId").text(),
            submitUrl = $parent.find(".submitUrl").text(),
            frequencyKeyName = "freq:" + alertContentId,
            data = {
                alertContext : alertContext,
                alertDescription : alertContextTitle,
                update : "true",
                alertScopeObjectId : alertContentId,
                alertFrequency : "HOUR",
                enabledKeyName : "on"
            },
            temp = data.enabledKeyName,
            isContentAlertType = alertContext.match("citation|correction") !== null ? true : false,
            isTopicAlertType = alertContext.match("topic") !== null ? true : false;

        if (isContentAlertType) {
            data.contentAlert = temp;
        } else {
            data["enabled:" + alertContentId] = temp;
        }
        
        if(isTopicAlertType){
        	AIPApp.displaySmallDialog(e, '#topicAlertDialog', null, $('#successfulTopicAlert').html(), "220", "165", "right top", null, "dsaTopicAl", null);
        }

        //float: right;  margin: 10px 0px;
        // delete data.enabledKeyName;
        $.post(submitUrl, data, function(resp) {
            $parent.find("span.addAlertLinkCont").addClass("hiddenElement");
            $parent.find(".successMessage").removeClass("hiddenElement");
        });
    });

    $(".alertLink").click(function(e) {
        e.preventDefault();
        $("#alertForm").submit();
    });
    
    $(".childTopicDialogTrigger").click(function(e) {
    	e.preventDefault();
    	AIPApp.displaySmallDialog(e, '#topicAlertDialog', null, $('#childTopicFyi').html(), "220", "165", "right top", null, null, "Close");
    });
    
    // Check to see if the Related tab is loaded or not... @TODO should this happen on every page?
    AIPApp.checkRelatedTabChange();

    // Functions for setting the first three latest articles to visible and others hidden on  journal homepage
    $("#journal").find(".toc .publistwrapper ul.togglecontent > li").not(".articleMetadata ul.togglecontent > li").each(function(index) {
        var $here = $(this);
        if ($here.is(".odd, .even")) {
            $here.removeClass("initialHide");
            // Hide if more than 3 (zero-based index) in  list...
            if (index > 2) {
                $here.addClass("initialHide");
            }
        }
    });

    $("#journal").find(".showOtherLatestArticles").on("click", "a.moreLink2, a.lessLink2", function(e) {
    	AIPApp.flipMoreLess2(e, ".publistwrapper", "li.initialHide");
    });

    $("#standardscontainer").find(".showOtherLatestStandards").on("click", "a.moreLink2, a.lessLink2", function(e) {
    	AIPApp.flipMoreLess2(e, "ul.flat", "li.initialHide");
    });

    /* this is used multiple places... */
    var moreLinkHtml = "",
	    moreImageHtml = "<img src='/images/aip/plus_icon.gif' alt='+' /> More",
	    lessImageHtml = "<img src='/images/aip/minus_icon.gif' alt='-' /> Less";

	    moreLinkHtml += "<a href='#' title='Link to more items in list' class='showmore std-display'><img src='/images/aip/plus_icon.gif' alt='+' /> More</a>";
    	moreLinkHtml += "<a href='#' title='Hide items in list' class='facethidetext std-display'><img src='/images/aip/minus_icon.gif' alt='-' /> Less</a>";

    // Set the +MORE for more like this, overriding J-P
    $(".seeMoreFacetsLink").html(moreLinkHtml);

    /* mostviewed - more or less is slightly special... */
    $("#mostviewed").on("click", ".morelink", function(e) {
        var $here = $(this);
        e.preventDefault();
        $here.parent().parent().find(".hide").show();
        $here.addClass("hideMoreCited").html(lessImageHtml).css({"background-image": "none"});
        $here.show();
    });
    $("#mostviewed").on("click", ".hideMoreCited", function(e) {
        var $here = $(this);
        e.preventDefault();
        $here.parent().parent().find(".hide").hide();
        $here.removeClass("hideMoreCited").html(moreImageHtml).css({"background-image": "none"});
        $here.show();
    });

    /*Applies to all more or less links - non ajax retrieval */
    $(document).on("click", "a.moreLink, a.lessLink", function(e) {
    	AIPApp.flipMoreLess(e, "ul", "li.hiddenjsdiv");
    });

    /* see more facets link show list - non ajax retrieval (or post ajax first retrieval and hide) */
    $(document).on("click", ".seeMoreFacetsLink a", function(e) {
        var $here = $(this);
        e.preventDefault();
        $here.closest("ul").find(".hiddenjsdiv").show();
        $here.next("a").show();
        $here.hide();
    });
    /* see more facets link hide list */ 
    $(document).on("click", ".facethidetext", function(e) {
        var $here = $(this);
        e.preventDefault();       
        if($here.parent('li').parent('ul').find(".ajaxhidden").length > 0){
        	$here.parent('li').parent('ul').find(".ajaxhidden").hide();
        }
        if($here.parent('li').parent('ul').find(".hiddenjsdiv").length > 0){
        	$here.parent('li').parent('ul').find(".hiddenjsdiv").hide();
        }
        $here.prev("a").show();
        $here.hide();
    });
    
    // Display/Hide dropdown menu for PTOL Daily Edition
    $("li#ptol_dailyeditiontab").mouseenter(function(e) {
        $(".dailyeditionmegamenu").show(250);
    });
      
    /* ptol nav megamenu - hide whenever outside of the megamenu container */
    $("#content, #sidebar_right, #ptol_banner, #ptol_abouttab,#ptol_follow, #ptol_printeditiontab, #ptol_jobstab, #ptol_hometab").mouseenter(function(e) {
        $(".dailyeditionmegamenu").hide(100);
    });
    
    // Display/Hide dropdown menu for PTOL About
    $("li#ptol_abouttab").mouseenter(function(e) {
        $(".aboutmegamenu").show(250);
    });
      
    /* ptol nav megamenu - hide whenever outside of the megamenu container */
    $("#content, #sidebar_right, #ptol_dailyeditiontab,#ptol_follow, #ptol_banner, #ptol_printeditiontab, #ptol_jobstab, #ptol_hometab").mouseenter(function(e) {
        $(".aboutmegamenu").hide(100);
    });

    // Display/Hide dropdown menu for PTOL follow
    $("li#ptol_follow").mouseenter(function(e) {
        $(".followmegamenu").show(250);
    });
      
    /* ptol nav megamenu - hide whenever outside of the megamenu container */
    $("#content, #sidebar_right, #ptol_subscribetab, #emptyEnd, #ptol_dailyeditiontab, #ptol_banner, #ptol_printeditiontab, #ptol_jobstab, #ptol_hometab").mouseenter(function(e) {
    	$(".followmegamenu").hide(100);
    });    
    // Display/Hide dropdown menu for PTOL follow
    $("li#emptyEnd").mouseenter(function(e) {
        $(".followmegamenu").hide(100);
    });
    
    // RWD Ptol tab 'Daily Edition'
    $("li#ptol_dailyeditiontab_mobile span.mobile-click-container").click(function(e){
    	
    	var menu = $(this).parent().find("#megamenu");
    	$(this).find("span").toggleClass("aip-icon-arrow-down4 aip-icon-arrow-up4");
    	$(menu).toggle(250);
    });
    // RWD Ptol tab 'Daily Edition'
    $("li#ptol_follow_mobile span.mobile-click-container").click(function(e){
    	
    	var menu = $(this).parent().find("#megamenu");
    	$(this).find("span").toggleClass("aip-icon-arrow-down4 aip-icon-arrow-up4");
    	$(menu).toggle(250);
    });
    // RWD Ptol tab 'Daily Edition'
    $("li#ptol_abouttab_mobile span.mobile-click-container").click(function(e){
    	
    	var menu = $(this).parent().find("#megamenu");
    	$(this).find("span").toggleClass("aip-icon-arrow-down4 aip-icon-arrow-up4");
    	$(menu).toggle(250);
    });      
    // RWD Ptol tab 'Daily Edition'
    $(".ptol-explore-tab").click(function(e){
    	$(this).find("span.chevron").toggleClass("aip-icon-arrow-down4 aip-icon-arrow-up4");
    });  
    
    /* toggle facet item LESS for ajax retrieved only */
    $(document).on("click", ".toggleajaxfacetitem .facethidetext", function(e) {
        var $here = $(this),
            $hereList = $here.parent().closest("ul");

        e.preventDefault();

        $hereList.find(".ajaxhidden").hide();
        $hereList.find(".seeAhahFacetsLink").show();
        $hereList.find(".seeAhahFacetsLink .showmore").show();
        $hereList.find(".showmore").removeClass("cursorWait").addClass("cursorPointer");
        $here.closest("ul").find("a.facethidetext").hide();
        $hereList.find(".toggleajaxfacetitem").remove();
    });
    
    /* toggle facet item MORE for ajax retrieved only (only happens first retrieval) */
    $(document).on("click", ".seeAhahFacetsLink a", function(e) {
            var $here = $(this),
                $ahahParent = $here.parent(".seeAhahFacetsLink"),
                $ahahGrdParent = $ahahParent.parent("ul"),
                url = $ahahGrdParent.find(".ahahurl").text(),
                ids = $ahahGrdParent.find(".ahahids").text(),
                names = $ahahGrdParent.find(".ahahnames").text(),
                values = $ahahGrdParent.find(".ahahvalues").text(),
                searchUrl = $ahahGrdParent.find(".ahahsearchurl").text(),
                data = {"ids": ids,
                    "names": names,
                    "values": values,
                    "searchurl": searchUrl
                };
            e.preventDefault();
            $here.addClass("cursorWait");

            $.ajax({
                type: "POST",
                url: url,
                data: data,
                success: function(resp, statusText) {
                    $ahahParent.after(resp);
                    var newHtml = "<a href='#' title='Hide items in list' class='facethidetext std-display'><img src='/images/aip/minus_icon.gif' alt='-' /> Less</a>";
                    $(".toggleajaxfacetitem").html(newHtml);
                    $(".toggleajaxfacetitem a").show();
                    $ahahParent.hide();
                },
                error: function(req, statusText) {
                },
                complete: function(req, statusText) {
                    $here.removeClass("cursorWait");
                }
            });
    });

    // Display/Hide dropdown menu for Publishers
    $(".navChevron").click(function(e) {
        var $this = $(this);
        e.preventDefault();
        if ($this.hasClass("chevronUp")) {
            $this.removeClass("chevronUp").attr("title", "View Publishers List");
        } else {
            $this.addClass("chevronUp").attr("title", "Close Publishers List");
        }
        $("#megamenu_pub").toggle("fast");
    });

    $(".js-mega-menu").click(function(e) {
        e.preventDefault();

        $(this).parent().find('.icon').toggleClass('aip-icon-arrow-down4').toggleClass('aip-icon-arrow-up4');
        
        $("#megamenu_pub").toggle("fast");
    });
    
    // In various places we need a little dialog box which is attached to a class rather than an id.
    $(document).on("click", ".signInOrRegister",function(e) {
        AIPApp.displaySmallDialog(e, "#signInOrRegisterDialog", "Sign in or Register", "Please sign in or register to use this feature", "300");
    });
    $(".completeProfile").click(function(e) {
        AIPApp.displaySmallDialog(e, "#signInOrRegisterDialog", "Complete your profile", "Please complete your profile to use this feature");
    });
    
    $( document ).on("click",".aipAddToFavouritesButton", function(e) {
    	var event,
    		statsUrl;

	    e.preventDefault();
		var trigelement = $(this);
		
		$(trigelement).parent().append('<span class="favUpdateWrappper" ><img class="favUpdating" src="/images/jp/spinner.gif" alt="updating favorites" /></span>');		
	    $(trigelement).parents(".favouritesForm").ajaxSubmit({
			success: function (response) {			
				$(".favUpdateWrappper").remove();
				if (trigelement.text().indexOf("Add") > -1) {
					trigelement.text("Remove from favorites");
				}else if (trigelement.text().indexOf("Remove") > -1) {
					trigelement.text("Add to favorites");
				}				
			}
		});
	    event = $(".favouritestatsevent").html();
	    statsUrl = hiddenContext + "/statslogredirect";
	    if (event !== null) {
	        $.post(statsUrl, {statsLogContents:event});
	    }
    });	
	
	
    /* */
    $(".moreSearchDetails").click(function(e) {
        var $sDialog = $("#searchExplanationTextDialogDisplay"),
            searchTermText = $(".searchExplanationTextDialogHiddenDisplay").html(),
            dWidth = 700,
            dHeight = 376;
        e.preventDefault();
        $sDialog.find(".searchTermDisplayDialog").remove();
        $sDialog.dialog({
            autoOpen : false,
            height : dHeight,
            modal : false,
            width : dWidth
        });
        $sDialog.append("<div class='searchTermDisplayDialog'>" + searchTermText + "</div>");
        $sDialog.dialog().parent(".ui-dialog").wrap("<div class='searchExplanationTextDisplayWrapper'></div>");
        $sDialog.dialog("open");
        $sDialog.show();
    });

    // Change requested by AIP to show exact phrase by default
    $('select#booleanselector option[value="searchoptionexact"]').attr("selected", "selected");

    if ($(".bookmarkcontainer").length > 0) {
        var bibsonomyUrl = "http://www.bibsonomy.org/ShowBookmarkEntry?url={u}&description={t}",
            citeulikeUrl,
            doiUrl,
            newTitle,
            newUrl,
            $startPoint,
            $target;

        if (aipProps.currentPage === 'home.markedlists') {
            $(".sharelinks").mouseover(function(e) {
                $target = $(this);
                $startPoint = $target.closest(".resultItem");
                doiUrl = $startPoint.find("span.doi a").attr("href");
                newTitle = $startPoint.find(".title a").text().replace(AIPApp.regExp.tags1, "").replace(AIPApp.regExp.spaces, " ");
                newUrl = window.location.protocol + "//" + window.location.host + $startPoint.find(".title a").attr("href");
                citeulikeUrl = "http://www.citeulike.org/posturl?username=&bml=popup&url=" + encodeURI(doiUrl) + "&title={t}";

                $.bookmark.addSite("bibsonomy", "Bibsonomy", "/images/aip/bibsonomy.png", "en", "other", bibsonomyUrl);
                $.bookmark.addSite("citeulike", "CiteULike", "/images/aip/citeulike.png", "en", "other", citeulikeUrl);

                $target.find(".moreshareoptions").bookmark({
                    url: newUrl,
                    title: newTitle,
                    icons: "/images/jp/bookmarks.png",
                    iconSize: 16,
                    sites: ["bibsonomy", "citeulike", "digg", "delicious", "google", "linkedin"]
                });
                $target.find(".moreshareoptions").show();
            });

            $(".sharelinks").mouseout(function(e) {
                $(this).find(".moreshareoptions").hide();
            });
        } else {
            doiUrl = $("span.doi a").attr("href");
            if (!doiUrl) {
                doiUrl = $(".itemCitation a").text();
            }
            citeulikeUrl = "http://www.citeulike.org/posturl?username=&bml=popup&url=" + encodeURI(doiUrl) + "&title={t}";

            $.bookmark.addSite("bibsonomy", "Bibsonomy", "/images/aip/bibsonomy.png", "en", "other", bibsonomyUrl);
            $.bookmark.addSite("citeulike", "CiteULike", "/images/aip/citeulike.png", "en", "other", citeulikeUrl);

            $(".moreshareoptions").bookmark({
                icons: "/images/jp/bookmarks.png",
                sites: [ "bibsonomy", "citeulike", "digg", "delicious", "google", "linkedin" ]
            });

            $(".sharelinks").click(function(e) {
                $(this).find(".moreshareoptions").toggle();
            });
            
        }
    }
		
		//if there is only one tab, don't shown the ham icon at mobile
		if($(".tabset li").length < 2 ){
				$(".ham-icon").remove();
				$(".tabset").parent("div").removeClass("ham-tabs");
				$(".tabset").parent("div").addClass("not-ham-tabs");
		}
    
    // Marker for "Log in in to see this feature" on article pages
    $(".tabset .disabled").each(function(index) {
        var $here = $(this),
            newMsg = "",
            newTitle = "",
            noData = $here.hasClass("nodata"),
            noAccess = $here.hasClass("noaccess"),
            notLoggedIn = $here.closest("div").hasClass("uli") ? false : true,
            msgs = [ $("#tab_title_msg0").text() || "No data available.",
                     $("#tab_title_msg1").text() || "Please log in to see this content.",
                     $("#tab_title_msg2").text() || "You have no subscription access to this content."
            ],
            title = $here.attr("title");
        
        
        //if there is data, but the user cannot access it
        if (noData !== true && noAccess === true) {
        	// determine if no access requires Log In prompt or No Subscription message
            newMsg = (notLoggedIn) ? msgs[1] : msgs[2];
        } else {
        	//if there is no data state this here
        	newMsg = msgs[0];
        }
        
        newTitle = (title ? title + " - " + newMsg : newMsg);
        $here.attr("title", newTitle);
    });
    
    /* default search text handler*/
    for (var i = 0; i < AIPApp.searchBoxArray.length; i++){
 	   //if the search box exists set up the focus/blur functionality
 	   if($(AIPApp.searchBoxArray[i]).length > 0){
 		   $($(AIPApp.searchBoxArray[i])).each(function(){
 				  AIPApp.defaultFocusAndBlur(AIPApp.searchBoxArray[i]);
 		   });		   
 	   }
    }

    // Marker for NOT YET IMPLEMENTED
    $("a[href='/mock/notimplemented'], a[href='/pub2web/mock/notimplemented']").each(function(index) {
        var $here = $(this),
            title = $here.attr("title"),
            msg1 = "FUNCTIONALITY NOT YET IMPLEMENTED";
        $here.attr("title", title ? title + " - " + msg1 : msg1);
    });

    // AHAH call for comments count - used for listing pages
    $(".replynodecommentcount").each(function(index) {
        var $here = $(this),
            itemId = $("#hiddenitemid", $here).text(),
            url = appUrls.commentcount1,
            data = {"itemId" : itemId},
            fragment = "";

        $.ajax({
            type: "POST",
            url: url,
            data: data,
            dataType: "html",
            success: function(resp, statusText) {
                // The response is an  entire page, so we  need to extract
                // the bits we need...
                fragment = $(".commentsAhahCountContainer", resp);
            },
            error: function(req, statusText, message) {
                fragment = "<p>An error occurred while retrieving comments.</p>";
            },
            complete: function(req, statusText) {
                $(".commentscountloading", $here).remove();
                $here.after(fragment);
            }
        });
    });

    // AHAH call for metrics
    $("#metrics").find("a").click(function(e) {
        var $metricsContainer = $(".metricsContainer"),
            startDate = $metricsContainer.find(".metricsPubDate").text(),
            endDate = $metricsContainer.find(".metricsEndDate").text(),
            webId = $metricsContainer.find(".metricsItemId").text(),
            url = appUrls.metrics + "?startDate=" + startDate + "&endDate=" + endDate + "&itemId=" + webId,
            ERR_MSGS = ["<p class='noMetricsData'>" + $("#metrics_msg0_label").text() + "</p>",
                        "<p class='metricsMsg'>" + $("#metrics_msg1_label").text() + "</p>",
                        "<p class='metricsMsg'>" + $("#metrics_msg2_label").text() + "</p>"
            ],
            pageTitle = $(".siqPageTitle").text(),
            doi = $(".siqDoi").text(),
            lineData1,
            lineData2,
            lineData3;

        // SIQ tagging request
        AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "Metrics");

        if ($metricsContainer.hasClass("retrieveMetrics")) {
            // Make the call...
            $.ajax({
                type: "GET",
                url: url,
                timeout: 90000,
                success: function(resp, statusText) {
                    $metricsContainer.find(".metricsDetails").append(resp);
                    $metricsContainer.removeClass("retrieveMetrics");
                },
                error: function(req, statusText, message) {
                    $metricsContainer.find(".metricsDetails").html(ERR_MSGS[1]).addClass("ajax-error");
                },
                complete: function(req, statusText) {
                    $(".itemMetricsLoading").remove();
                    var $table1 = $("#abstractDayView"),
                        table1HasData = ($table1.find("td").hasClass("noMetricsData") ? false : true),
                        graph1 = "graph1Output",
                        $table2 = $("#fulltextDayView"),
                        table2HasData = ($table2.find("td").hasClass("noMetricsData") ? false : true),
                        graph2 = "graph2Output",
                        $table3 = $("#metricTotals"),
                        // Notice the negation...
                        table3HasData = (!$table3.find("td").hasClass("noMetricsData") ? true : false),
                        graph3 = "graph3Output";

                    // Plot data from  Table 1...
                    if (table1HasData) {
                        AIPApp.displayGraphOrTable($table1, "line", graph1, "abstractDayView", ERR_MSGS[2]);
                    } else {
                        $("#" + graph1).append(ERR_MSGS[0]);
                    }
                    // Plot data from Table 2...
                    if (table2HasData) {
                        AIPApp.displayGraphOrTable($table2, "line", graph2, "fulltextDayView", ERR_MSGS[2]);
                    } else {
                        $("#" + graph2).append(ERR_MSGS[0]);
                    }
                    // Plot data from  Table 3...
                    if (table3HasData) {
                        AIPApp.displayGraphOrTable($table3, "pie", graph3, "metricTotals", ERR_MSGS[2]);
                    }
                }
            });
        }
    });

    // Global SIQ variables
    var SIQ = {
            webId: $(".siqItemId").text(),
            pageTitle: $(".siqPageTitle").text(),
            doi: $(".siqDoi").text(),
            eventType: $(".siqPub2webEventType").text()
        };

    // AHAH call for related tab required for SIQ tagging  request
    $("#related").find("a").click(function(e) {
        AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "Related");
    });

    // AHAH call for references tab required for SIQ tagging  request
    $("#references").find("a").click(function(e) {
        var isActive = $(".siqReferencesTabEnabled").text();
        if (isActive) {
            AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "References");
        }
    });

    // AHAH call for references tab required for SIQ tagging  request
    $("#citations").find("a").click(function(e) {
        var isActive = $(".siqCitationsTabEnabled").text(),
            itemId = $("#itemIdForCitations").text(),
            data = {
                "requesttype": "citations",
                "fmt": "ahah",
                "contentitem": itemId
            },
            url = appUrls.citations;
        if (isActive) {
            AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "Citations");
        }

        $.ajax({
            type: "GET",
            data: data,
            url: url,
            dataType: "html",
            success: function(resp, statusText) {
                $(".citingArticlesLoading").remove();
                if (resp !== null) {
                    $("#citationContent").get(0).innerHTML = resp;
                }
            },
            error: function(req, statusText, message) {
                $(".citingArticlesLoading").remove();
            }
        });
    });

    // AHAH call for abstract tab required for SIQ tagging  request
    $("#abstract").find("a").click(function(e) {
        AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "Abstract", "true");
    });

    // AHAH call for data and media tab required for SIQ tagging  request
    $("#dataandmedia").find("a").click(function(e) {
        AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "DataAndMedia");
    });

    // AHAH call for PDF Full Text click required for SIQ  tagging request
    $(".fulltext .pdf a").click(function(e) {
        if (_gaq) {
            _gaq.push(['_trackEvent', 'Download', 'PDF', this.href]);
        }
        AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "FulltextPDFDownload");
    });

    // SIQ tagging request for on load requests, i.e. not action related such as clicks
    AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, SIQ.eventType);

    // The below unbinds the submit action within the jp site.js  and instead we want to
    // to override with the one from the instance, which is below.
    $("#global-search-form").unbind("submit");

    // override submit action for quick search
    $("#global-search-form").submit(function(e) {
        var $searchBox = $("#quickSearchBox"),
            term1 = $searchBox.val(),
            term2 = term1.replace(AIPApp.regExp.tags2, ""),
            checkTerm = $('#searchBox').hasClass('withinPub') ? AIPApp.defaultSearchTermWithinOption : AIPApp.defaultSearchTerm;
        
        if (term2 && term2 !== checkTerm) {
            $searchBox.val(term2);
            $(this).unbind("submit");
            // Log siq event
            AIPApp.siq(appUrls.siq, SIQ.webId, SIQ.pageTitle, SIQ.doi, "Search", null, term2, function(contents) {
                // log pub2web event
                $.get(appUrls.statslogwrapper, {searchterm : term2}, function(contents) {
                    $.post(appUrls.statslogredirect, {statsLogContents : contents});
                });
            });
        } else {
            e.preventDefault();
            $searchBox.focus();
        }
    });
    
    /*Quick Search - Volume Page Search*/
   /*mixed script/jsp in volumePageSearch.tag handles #volumePageLink.downarrow click */
    $("#volPageContainer").on("click", "#volumePageLink.open", function(e) {
    	e.preventDefault();
    	$('#volumePageLink').removeClass('open').addClass('closed');
    	$("#volumePageLink a span").removeClass("uparrow").addClass("downarrow");
    	$("#volPageMenu").slideUp();     
    	$('#volumePageLink .js-icon').toggleClass("aip-icon-arrow-down4").toggleClass("aip-icon-arrow-up4");
    });
    // Volume page search, send stats first submit and show message if no pub selected
    var volPageStatSent = false;
    $("#volumepage-search-form").submit(function(e) {        
        var $t = $(this),
	        term = "",
	        publicationStr = "",
	        publication;
        
        //get publication value
        publication = $('select[name="value8"]').length ? $('select[name="value8"]').val() : input[name="value8"].val();

        //first check if they entered anything
        if (!publication.length) {
        	alert("Please choose a publication first!");
            return false;
        } else {
        	//set it to open tab for MagazineContent if PTOL chosen
            if (publication === "aip/magazine/physicstoday") {
                $('#quickSearchResultCategory').val('MagazineContent');
            }
            //if stats not sent... send
            if(!volPageStatSent){
                //get publication string (would there ever be more than one?)
            	$('select[name="value8"] :selected').each(function(index) {
                    publicationStr += $(this).val() + ",";
                });
                publicationStr = publicationStr.slice(0, publicationStr.length - 1);
                
	            $.get(appUrls.statslogwrapper, {searchterm: term, publicationids : publicationStr}, function(contents) {
	                $.post(appUrls.statslogredirect, {statsLogContents : contents}, function() {
	                	volPageStatSent = true;
	                    return true;
	                });
	            });
            } else {
            	return true;
            }
        }
    });
    
    
    //Sort by options 1-3
    //1.Relevance
    $("#sortRelevance").click(function(e) {
        e.preventDefault();
        $("#sortForm input").each(function(index) {
            var $here = $(this);
            if (($here.attr("name") === "sortDescending") || ($here.attr("name") === "sortField")) {
                $here.remove();
            }
        });
        $("#sortForm").submit();
    });
    //2. oldest first
    $("#sortOldest").click(function(e) {
        AIPApp.sortByDate(e, "OLD");
    });
    //3. newest first
    $("#sortNewest").click(function(e) {
        AIPApp.sortByDate(e, "NEW");
    });

    //submits marked list / favorites form
    $(".markedList").click(function(e) {
        $("#markListForm").submit();
    });

    if ($(".searchcompletetopic").length > 0) {
        $(".searchcompletetopic").autocomplete({
            source: appUrls.autosuggest,
            minLength: 3,
            select: function(event, ui) {
                $(".searchcompletetopic").val(ui.item.label);
                $("#topic-search-form").submit();
            }
        });
    }

    $(".submit-parent-form").click(function(e) {
        var $form = $(this).closest("form");
        if ($form) {
            $form.submit();
        }
    });

    // overwritting JP version PLUS additional code to hide  extra data shown
    $("#morelikethis").on("click", ".morelink", function(e) {
        var $here = $(this),
            $theLink = $(e.target);
        $here.show(); // JP versions hides the container so having to show it again.
        $here.find("a").css({"display": "inline-block"});

        if ($theLink.hasClass("more")) {
            $theLink.hide().next().show();
            $here.siblings("ul").find(".hide").show();
        } else {
            $theLink.hide().prev().show();
            $here.siblings("ul").find(".hide").hide();
        }
    });

    // Hide the entire comments section if commenting is  disabled...
    $(".commentsDisabled").parents(".commentsContainer").hide();

    // If there is a slideshow, check that at least one rollover  image is actually showing...
    if ($("#slideshow").length > 0) {
        var $slideShow = $("#slideshow");
        if ($slideShow.find("li img.activeImage").length === 0) {
            $slideShow.find("li img").eq(0).addClass("activeImage");
            $slideShow.find("li").eq(0).addClass("activeItemViewed");
        }
    }

    // Change the image display on rollover...
    $("#cyclenav").find("li").mouseenter(function(e) {
        var $here = $(this);
        $here.siblings().removeClass("activeText");
        $here.addClass("activeText");
        $("#slideshow").find(".direction-arrow").removeClass("activeImage");
        $("#slideshow").find("li").removeClass("activeItemViewed");

        $("#slideshow li").eq($here.index()).find(".direction-arrow").addClass("activeImage");
        $("#slideshow li").eq($here.index()).addClass("activeItemViewed");
        $("#slideshow").find("img").removeClass("activeImage").eq($here.index()).addClass("activeImage");
    });;

    // Check on empty adverts and collapse the space...
    $(".advertRight1, .advertRight2, .advertRight3").each(function(index) {
        var $here = $(this),
            emptyGif = /empty\.gif/,
            adHref = $here.find("a").attr("href");
        if (emptyGif.test(adHref)) {
            $here.addClass("hideMe");
        }
    });

    // Hide the Print button if IE8 or IE9
   /* if ($(".printButton").length > 0) {
        if ($.browser.msie) {
            $(".printButton").addClass("hideMe");
        }
    }*/

    // Replace the VIEW / HIDE controls on the 3rd party results page...
    if ($("#relatedDatabasesSearchResults").length > 0) {
        var $here1,
            $here2,
            hideHtml,
            viewHtml;

        $("#relatedDatabasesSearchResults").find(".resultItem").each(function(index) {
            $here1 = $(this);
            $here1.find(".showhide").addClass("std-display");
            $here2 = $here1.find(".plus");
            viewHtml = $here2.html().replace("+", "<img alt=\"+\" src=\"/images/aip/plus_icon.gif\" />");
            $here2.html(viewHtml);
            $here2 = $here1.find(".minus");
            hideHtml = $here2.html().replace("-", "<img alt=\"-\" src=\"/images/aip/minus_icon.gif\" />");
            $here2.html(hideHtml);
        });
    }

    $("a.tandcLink").click(function(e) {
        e.stopPropagation();
        e.preventDefault();
        window.open(this.href, "TandCWindow", winProps2);
    });

    $(".sortPendingType").click(function(e) {
        e.preventDefault();
        $("#search_sort_form_ascending").val("true");
        $("#search_sort_form_sortby").val($(this).attr("href"));
        $("#search_sort_form").submit();
    });

    // Do we need to display comments counts?
    if ($(".showCommentsCounts").length > 0) {
        var arrLen = 0,
            cmtHtml = "",
            commentUrl = "",
            currItem,
            currCount,
            currTitle,
            dataStr = "",
            i = 0,
            idArr = [],
            idList = "",
            mStr = "",
            respLen = 0,
            tmp = 0,
            $target;
        if ($(".ahahTocArticles").length) {
            idList = $(this).find("input[name='articleIds']").val();
            if (idList) {
                idArr = idList.split(",");
                arrLen = idArr.length;
                for (i = 0; i < arrLen; i++) {
                    dataStr += "itemId=" + idArr[i] + "&";
                }
                commentUrl = appUrls.commentcount2;
                $.ajax({
                    type : "POST",
                    url : commentUrl,
                    data : dataStr,
                    success : function(resp, statusText) {
                        if (resp) {
                            respLen = resp.length;
                            for (i = 0; i < respLen; i++) {
                                currCount = resp[i].cmtcount;
                                currItem = resp[i].itemId;
                                if (currCount > 0) {
                                    // Split the itemId
                                    tmp = currItem.indexOf("/content");
                                    if (tmp !== -1) {
                                        mStr = hiddenContext + currItem.substr(tmp);
                                        $target = $(".articleTitle").find("a[href='" + mStr + "']");
                                        if ($target.length > 0) {
                                            cmtHtml = "";
                                            cmtHtml += "<span class='bookmark-separator'>";
                                            cmtHtml += "<img src='/images/aip/icons_separator.png' width='2' height='16' />";
                                            cmtHtml += "</span><img src='/images/aip/comment_icon_display.png' alt='' />";
                                            cmtHtml += "<span class='commentCount'>(" + currCount + ")</span>";
                                            $target.append(cmtHtml).hide().fadeIn(AIPApp.fades.medium);
                                        }
                                    }
                                }
                            }
                        }
                    },
                    error : function(req, statusText) {
                        if (AIPApp.consoleOK) {console.log("showCommentsCount(): Error '" + statusText + "'...");}
                    }
                });
            }
        }
    }

    $("#related").find("a").click(function(e) {
        if ($("#hiddenmorelikethisidsforclick").length > 0) {
            var data = {
                    "pubrelatedcontentids": $("#hiddenmorelikethisidsforclick").text(),
                    "doi": $("#hiddenmorelikethisdoi").text(),
                    "webid": $("#hiddenmorelikethiswebid").text(),
                    "fields": $("#hiddenmorelikethisfields").text(),
                    "restrictions": $("#hiddenmorelikethisrestrictions").text(),
                    "number": $("#hiddenmorelikethisnumber").text(),
                    "numbershown": $("#hiddenmorelikethisnumbershown").text()
                };

            $.ajax({
                type : "POST",
                url : appUrls.morelikethis,
                data : data,
                dataType : "text",
                success : function(resp) {
                    var target = $("#morelikethiscontent").get(0);
                    target.innerHTML = resp;
                    MathJax.Hub.Queue(["Typeset", MathJax.Hub, target ]);
                    $(".morelikethisloading").remove();
                    $("#hiddenmorelikethisidsforclick").remove();
                }
            });
        }
    });

    $("#dataandmedia").find("a").click(function(e) {
        if ($("#hiddenDataMediaWebid").length > 0) {
            var itemId = $("#hiddenDataMediaWebid").text(),
                url = hiddenContext + itemId + "/datamedia?fmt=ahah";
            $.ajax({
                type: "GET",
                url: url,
                dataType: "text",
                success: function(resp, statusText, req) {
                    var target = $(".dataandmedia").get(0);
                    if (target) {
                        target.innerHTML = resp;
                        MathJax.Hub.Queue(["Typeset", MathJax.Hub, target]);
                    }
                },
                complete: function(req, statusText) {
                    $(".itemDataMediaLoading").remove();
                    $("#hiddenDataMediaWebid").remove();
                }
            });
        }
    });

    $("span.addToCollection button").click(function(e) {
        var data = {},
            idList = "",
            memberList = "",
            collectionId = $("#collectionId").text(),
            collectionUrl = hiddenContext + collectionId,
            submitUrl = appUrls.gatheritems;

        $("#searchResultsContainer").find(".gatherItems input").each(function(index) {
            var $thisItem = $(this);
            if ($thisItem.prop("checked")) {
                idList += index + ": " + $thisItem.val() + "\n";
                if (memberList) {
                    memberList = memberList + "," + $thisItem.val();
                } else {
                    memberList = $thisItem.val();
                }
            }
        });

        data = {
            collectionId : collectionId,
            members : memberList
        };

        if (idList) {
            $.ajax({
                type : "POST",
                url : submitUrl,
                data : data,
                success: function(resp, statusText) {
                    window.location = collectionUrl;
                },
                error : function(req, statusText) {
                    alert("Add to Collections error: " + statusText);
                }
            });
        } else {
            alert("Search Results:\n\nNo items were selected.");
        }
    });

    $("span.addAllToCollection input").click(function(e) {
        var $here = $(this),
            $startPoint = $("#searchResultsContainer");
        if ($here.prop("checked")) {
            $startPoint.find("input[type='checkbox']").prop("checked", true); 
        } else {
            $startPoint.find("input[type='checkbox']").removeAttr("checked");
        }
    });

    if ($(".collectionsContainer").length) {
        $(".collectionsContainer").find(".articleMetadata .accessIcons").html("<img src='/images/aip/icon_collection_stacked.png' alt='collection icon' title='Collection icon' />");
    }
    
    /* To fix RSS feeds */
	if($('.section1').length > 0){
		AIPApp.encodeHeadingForRss('.section1');
	}
	if($('.tocheading2').length > 0){
		AIPApp.encodeHeadingForRss('.tocheading2');
	}
	if($('.tocheading3').length > 0){
		AIPApp.encodeHeadingForRss('.tocheading3');
	}
	
    
    /*
     * Refine Search Work
     * Part 1. 	Results on search_results.jsp for site search
     * Part 2. 	Results on search_results.jsp for topics home page search
     * Part 3. 	Results on concept.jsp via ahah for a topic page* not located in this file
     * 			-See searchresults-ahah.js for Part 3
     */    
    // Part 1. & 2.
    if($("#searchrefineform").hasClass('lnk_search')){
    	$("#searchrefineform").submit(function(e) {
	        var $searchForm = $(this), 
	            $searchBox = $searchForm.find("input[type='text']"),
	            refinementNumber = $searchForm.find("input[name='refinementNumber']").val(),
	            dataObj = {},
	            keyCount = 0,
	            keyList = [],
	            newDigit = 0,
	            newName = "",
	            newValue = "",
	            origParams,
	            origUrl,
	            term1 = $searchBox.val(),
	            term2 = term1.replace(AIPApp.regExp.tags2, ""),
	            thisPage,
	            urlObj;
		        //e.preventDefault();
	        
		        if (term2 && term2 !== AIPApp.defaultRefineTerm) {
		        	//if it exists and isn't the default text
		            $searchBox.val(term2);
		            //set the value to cleaned up version of the term
		            
		            //Get original URL with search parameters
		            if ($searchForm.hasClass("lnk_search")) {
		                origUrl = $("#searchParameters").text();
		            }
		            
		            //get params from current URL
		            urlObj = AIPApp.parseUrl(origUrl);
		            origParams = urlObj.params;
		            keyList = Object.keys(origParams).sort().reverse();
		            keyCount = keyList.length;
		            
		            if (keyCount) { //if the search params we found return true
		                return true;
		            } else {
		                e.preventDefault();
		            }
		            
		            //remove these options from the return, physics today and db tabs
		            removeRefinementFromLinks();
		            
		        } else { //if input is the default text, prompt user
		            e.preventDefault();
                            $searchBox.focus();
		        }
		    });
    }
    
    if($("#searchParameters").text().indexOf("801") >= 0 && $("#searchrefineform").hasClass('lnk_search')){
    	removeRefinementFromLinks();
    }
    
    function removeRefinementFromLinks() {
    	var returnLink = $('.searchRefineReturn a'),
		sortFormInput = $('#sortForm input'),
		saveRefineFormInput,
		baseHref = $("#hiddenContext").text() + "/search",
        newHref = "",
        newRP_Href,
        newPT_Href,
        newRD_Href,
        params,
        paramsForNew = ["?"],
        t;
    	
    	//use this form to create new base search url
    	params = $("#sortForm").serialize();
    	params = params.split("&");   	
    	for (t = 0; t < params.length; t++){
    		if(params[t].indexOf("80") < 0){
    			if(params[t].indexOf("refine") < 0){
    				//save this param for new href
    				paramsForNew.push(params[t]);
    			}
    		}
    	}
    	newHref = baseHref + paramsForNew.join("&");
    	
    	//remove any related database portions from url
    	newHref = newHref.replace('/search/thirdparty/pubmed', '/search');
    	newHref = newHref.replace('/search/thirdparty/arxiv', '/search');
    	
    	if(!$('.noResultsFound').length > 0){
    		//if there are results you can update the return link
	    	if($('#searchResultsTabs').length > 0){
		    	//set up specifics for tabbed links
		    	newRP_Href = newHref.replace('MagazineContent', 'ResearchPublicationContent');		    	
		    	newPT_Href = newHref.replace('ResearchPublicationContent', 'MagazineContent');		    	
		    	newRD_Href = newHref.replace('MagazineContent', 'ResearchPublicationContent');
		    	newRD_Href = newRD_Href.replace('/search', '/search/thirdparty/arxiv');
		
		    	//replace links
		    	$('#researchpublications a').attr('href', newRP_Href);
		    	$('#physicstoday a').attr('href', newPT_Href);
		    	$('#relatedDatabases a').attr('href', newRD_Href);
	    	}
	    
    	
	    	if( $('#researchpublications').hasClass('active') ) {
	    		returnLink.attr("href", newRP_Href);
	    	} else if ( $('#physicstoday').hasClass('active')) {
	    		returnLink.attr("href", newPT_Href);
	    	} else {
	    		returnLink.attr("href", newHref);
	    	}
    	} else {
    		//if there are no results
    		newHref = $('#searchParameters').text().replace(/&value80[1-9]=[^&]*/g, "");
    		newHref = newHref.replace(/&option80[1-9]=[^&]*/g, "");
    		newHref = newHref.replace(/&operator80[1-9]=[^&]*/g, "");
    		newHref = newHref.replace(/&refinementNumber=[^&]*/g, "");
    		//console.log(newHref);
    		returnLink.attr("href", newHref);
    		
    		if($('#searchResultsTabs').length > 0){
		    	//set up specifics for tabbed links
		    	newRP_Href = newHref.replace('MagazineContent', 'ResearchPublicationContent');		    	
		    	newPT_Href = newHref.replace('ResearchPublicationContent', 'MagazineContent');		    	
		    	newRD_Href = newHref.replace('MagazineContent', 'ResearchPublicationContent');
		    	newRD_Href = newRD_Href.replace('/search', '/search/thirdparty/arxiv');
		
		    	//replace links
		    	$('#researchpublications a').attr('href', newRP_Href);
		    	$('#physicstoday a').attr('href', newPT_Href);
		    	$('#relatedDatabases a').attr('href', newRD_Href);
	    	}
    	}   		
    }

    //opens first year section in the list 
    $(".issuecontents > .issueBar .issue-list li:first a").click();

    $(".sectionBar a.expandLinkClass").click(function(){
    	$(this).closest(".issueBar").find(".togglecontent ").toggle();
    	$(this).find("span.open-close").toggleClass("aip-icon-plus3 aip-icon-minus3");
    });
    $(".magnifyImage").click(AIPApp.magnifyImage);

    // In some cases ampersands cause problems...
    $(".browsefacetterm").each(AIPApp.replaceAmpsInFacets);
    $(".articleMetadata").each(AIPApp.replaceAmpsInDesc);
    $(".publisherinfodiv p").each(AIPApp.replaceAmpsInDesc);

    // KLOC : Click event needs to be re-registered onto the button after 1 result set returned 
    // or event listener needs to be able to cope with dynamic data (.live not supported so used .on with element
    // that remains a constance on the page - it was not working previously.
    // .seemorepostsWrapper gets added into the page multiple times so was not suitable.
    
    $(".blogheader").on("click", ".showMoreBlogPosts", function(e){
        var $this = $(this),
        	itemId = $(".hiddenWeblogWebid").text(),
        	month = $(".hiddenWeblogMonth").text(),
        	requestedPage = $this.parent(".seemoreposts").find(".hiddenRequestedPageNumber").text(),
        	hiddenContext = $("#hiddenContext").text(),
        	url = "";       
        	
        if ( requestedPage == '') {
        	requestedPage = 2;
        }
        
        $(".seemorepostsWrapper").append('<div class="morepostsloadingwrappper"><img class="morePostsLoading" src="/images/jp/spinner.gif" alt="Loading posts" /></div>');
        url = hiddenContext + itemId + "/moreposts?month=" + month + "&requestedPage=" + requestedPage;

        $.ajax({
            type: "GET",
            url: url,
            timeout: 90000,
            success: function(resp, statusText) {
            	$("#moreblogposts").append(resp);          
            	
            	$.cachedScript("/js/aip/blogs.js");
            	$this.parent(".seemoreposts").remove();
            },
            error: function(req, statusText, message) {
            },
            complete: function(req, statusText) {
                $(".morepostsloadingwrappper").remove();
            }
        });
    });
    
    /*
	 * set up affiliations search link if institution page dne
     * on article page, any location using displayAffiliationDetails.tag
     */
    if($('.affilLinkToEncode').length > 0){
    	$('.affilLinkToEncode').each(function(){
    		$a = $(this),
    		affilLink = $a.attr('href'),
    		instName = $a.text(),
    		newAffilLink = "";
    		
    		// instName = instName.split(',');
    		// instName = encodeURI(instName[0]);
    		instName = encodeURI(instName);
    		newAffilLink = affilLink.replace("ENCODEDINSTNAME", instName);
 
    		$a.attr('href', newAffilLink);    		
    	});
    }
    
    /* For User Admin textarea fields - Bug: 48868*/
    var propertyChangeUnbound = false;
    $("#save textarea").bind("propertychange", function(e) {
       if (e.originalEvent.propertyName === "value") {
          $("#saveaccountbutton").attr("disabled","");
       }
    });
    $("#save textarea").bind("input", function() {
       if (!propertyChangeUnbound) {
          $("#save textarea").unbind("propertychange");
          propertyChangeUnbound = true;
       }
       $("#saveaccountbutton").attr("disabled","");
    });
    
    return false;
}); /**
* END of document ready
*/



// Based on some MDN code
var libCookies = {
    earliestDate: "Thu, 01 Jan 1970 00:00:00 GMT",
    latestDate: "Fri, 31 Dec 9999 23:59:59 GMT",
    /**
     * Gets a cookie with various parameters...
     *
     * @param {string}        Cookie name
     */
    getCookie: function (cName) {
        return decodeURIComponent(document.cookie.replace(new RegExp("(?:(?:^|.*;)\\s*" + encodeURIComponent(cName).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=\\s*([^;]*).*$)|^.*$"), "$1")) || null;
    },
    /**
     * Sets a cookie with various parameters...
     *
     * @param {string}        Cookie name
     * @param {string}        Cookie value
     * @param {number | date} Cookie age or expiry date
     * @param {string}        Cookie path
     * @param {string}        Cookie domain
     * @param {true | false}  Flag indicating secure (or not)
     */
    setCookie: function (cName, cValue, cEnd, cPath, cDomain, cSecure) {
        var sExpires = "";
        // Disallow no name or cookie keywords as names
        if (!cName || /^(?:expires|max\-age|path|domain|secure)$/i.test(cName)) {
            return false;
        }
        if (cEnd) {
            // How is the end point defined?
            switch (cEnd.constructor) {
            case Number:
                sExpires = cEnd === Infinity ? ";expires=" + libCookies.latestDate : ";max-age=" + cEnd;
                break;
            case String:
                sExpires = ";expires=" + cEnd;
                break;
            case Date:
                sExpires = ";expires=" + cEnd.toUTCString();
                break;
            }
        }
        document.cookie = encodeURIComponent(cName) + "=" + encodeURIComponent(cValue) + sExpires + (cDomain ? ";domain=" + cDomain : "") + (cPath ? ";path=" + cPath : "") + (cSecure ? ";secure" : "");
        return true;
    },
    /**
     * Removes a cookie
     *
     * @param {string}        Cookie name
     * @param {string}        Cookie path
     * @param {string}        Cookie domain
     */
    removeCookie: function (cName, cPath, cDomain) {
        if (!cName || !this.hasItem(cName)) {
            return false;
        }
        document.cookie = encodeURIComponent(cName) + "=;expires=" + libCookies.earliestDate + ( cDomain ? ";domain=" + cDomain : "") + ( cPath ? ";path=" + cPath : "");
        return true;
    },
    /**
     * Checks that a cookie exists
     *
     * @param {string}        Cookie name
     */
    hasCookie: function (cName) {
        return (new RegExp("(?:^|;\\s*)" + encodeURIComponent(cName).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=")).test(document.cookie);
    }
};

/* taken out of sitejp.js (deing delted) and put into instance and not JP site.js to avoid issues on other instances */
/* @TODO remove this code when we switch to use responsive-tabs.js */
/* Handle switching tabs */
$(".tabset .active a").click(function(e) {
    e.preventDefault();
});
$(".tabset li").click(function() {
    var here = $(this);
    if (here.find("a").hasClass("externaltab")) {
        return true;
    } else {
        if ($("#tabbedpages").size() > 0) {
            if (!here.find("a").hasClass("disabled")) {
                var idName = here.attr("id");
                $(".tabset").find("li").each(function(){
                    $(this).removeClass("active");
                });
                here.addClass("active");
                $("#tabbedpages").find(".tabbedsection").each(function(){
                    if ($(this).hasClass(idName)) {
                        $(this).show();
                    } else {
                        $(this).hide();
                    }
                });
            }
            return false;
        } else {
            return true;
        }
    }
});


/*
KLOC: Function to replace the sortby label to the current sort type


$(document).ajaxComplete(function() {
	//if page uses sorting function
	if($('.sortBy').length > 0){
		$('.sortBy').each(function(){
			var currentSortType,
			 staticLabel,
			 newStaticLabel;
			
			currentSortType= $(this).find('.inactiveLink').html();
			staticLabel = $(this).find('.mobileLabel').html()
			
			//console.log(currentSortType + ' : Current sort type');
		    //console.log(staticLabel + ' : current active label');
		    
		    if(typeof currentSortType !== 'undefined' && typeof staticLabel !== 'undefined'){
		    	newStaticLabel = currentSortType + ' ' + staticLabel.substring(staticLabel.indexOf('<'));     
		    	//console.log(newStaticLabel + ' : new label');
		        $('.mobileLabel').html(newStaticLabel);
		    }
		});
	}
});

*/


